import React, { Component } from 'react';
import * as Charting from 'chart-library';
import MindFusion from 'mindfusion-common';


class MekkoChart extends Component {

constructor(props) {
		super(props);

		this.el = React.createRef();
	
	}
	
	componentDidMount() {

		var chart = new Charting.Controls.BarChart(this.el.current, Charting.BarLayout.Stack);
		chart.licenseLocation = './chart_lic.txt'; 
		chart.barSpacingRatio = 0;
		
		chart.titleMargin = new Charting.Margins(0, 20, 0, 0);
		chart.showLegend = true;
		chart.title = "Student Admission";

		// create chart brushes
		var thirdBrush = new MindFusion.Charting.Drawing.Brush("#FFDDCE");
		var secondBrush = new MindFusion.Charting.Drawing.Brush("#FE86A4");
		var firstBrush = new MindFusion.Charting.Drawing.Brush("#78C0F9");
		var darkGrayBrush = new MindFusion.Charting.Drawing.Brush("#737373");

		var labels = [
			"Biology", "Math", "Chemistry", "IT", "Foreign\nLanguages", "Economics"
		];


		// create the data series
		var series = new MindFusion.Charting.Collections.ObservableCollection(
		[
			new Charting.SimpleSeries(new MindFusion.Charting.Collections.List([23, 74, 58, 62, 22, 29]), 
			new MindFusion.Charting.Collections.List([23, 74, 58, 62, 22, 29])),
			new Charting.BarSeries(new MindFusion.Charting.Collections.List([77, 26, 42, 38, 78, 71 ]),
			new MindFusion.Charting.Collections.List([77, 26, 42, 38, 78, 71 ]), null, labels)		
		]);

		series.item(0).title = "Boys";
		series.item(0).supportedLabels = Charting.LabelKinds.ToolTip;
		series.item(1).supportedLabels = Charting.LabelKinds.ToolTip | Charting.LabelKinds.XAxisLabel;
		series.item(1).title = "Girls";

		chart.series = series;
         
		//chart settings
		chart.showXCoordinates = false;
		chart.xAxisTickLength = 0;		
		chart.showToolTips = true;
		chart.showLegendTitle = false;
		

		//axis settings
		chart.yAxis.title = "Percent";
		chart.yAxis.interval = 10;
		chart.yAxis.maxValue = 101;

		chart.xAxis.interval = 1;
		chart.xAxis.minValue = 0;
		chart.xAxis.maxValue = 7;
		chart.xAxis.title = "";
		


		// assign one brush per series
		chart.plot.seriesStyle = new Charting.PerSeriesStyle(new MindFusion.Charting.Collections.List([firstBrush, secondBrush]),
		new MindFusion.Charting.Collections.List([thirdBrush]), new MindFusion.Charting.Collections.List([6]));
		//appearance settings
		chart.theme.legendBackground = thirdBrush;
		chart.theme.legendBorderStroke = darkGrayBrush;
		chart.theme.dataLabelsBrush = darkGrayBrush;
		chart.theme.dataLabelsFontSize = chart.theme.axisLabelsFontSize = 14;
		chart.theme.axisTitleFontSize = 16;
		chart.theme.axisLabelsFontSize = 14;
		chart.theme.axisTitleFontName = "Verdana";
		chart.theme.axisLabelsFontName = "Verdana";
		chart.theme.dataLabelsFontName = "Verdana";
		chart.theme.titleBrush = new MindFusion.Charting.Drawing.Brush("#737373");
		chart.theme.titleFontName = "Verdana";
		chart.theme.highlightStroke = new MindFusion.Charting.Drawing.Brush("#5870a7");
		chart.theme.highlightStrokeThickness = 3;
		chart.theme.highlightStrokeDashStyle = Charting.Drawing.DashStyle.Dot;


		// customize tooltips
		Charting.ToolTip.position = new MindFusion.Drawing.Point (20, 20);
		Charting.ToolTip.brush = new MindFusion.Charting.Drawing.Brush("#fafafa");
		Charting.ToolTip.pen = new MindFusion.Charting.Drawing.Pen("#9caac6");
		Charting.ToolTip.textBrush = darkGrayBrush;
		Charting.ToolTip.horizontalPadding = 6;
		Charting.ToolTip.verticalPadding = 4;
		Charting.ToolTip.font = new Charting.Drawing.Font("Verdana", 12, Charting.Drawing.FontStyle.Regular);

		chart.draw();
	
	}	
	
	
render() {
		return (
			<div>
				<canvas width="1000px" height="500px" ref={this.el}></canvas>
			</div>
		);
	}

}

export default MekkoChart;





























